<?php declare(strict_types=1);
/**
 * JTL Plugin
 * Copyright (C) 2011 - 2020 Andreas Petermann
 *
 * PHP version 7.2+
 *
 * @copyright css-umsetzung
 * @author Andreas Petermann <info@css-umsetzung.de>
 * @package ara_language
 * @license GNU
 * @version 1.00
 *
 */

namespace Plugin\ara_language;

use JTL\Alert\Alert;
use JTL\Catalog\Category\Kategorie;
use JTL\Catalog\Product\Artikel;
use JTL\Events\Dispatcher;
use JTL\Events\Event;
use JTL\Helpers\Form;
use JTL\Helpers\Request;
use JTL\Link\LinkInterface;
use JTL\Plugin\Bootstrapper;
use JTL\Shop;
use JTL\Smarty\JTLSmarty;
use Plugin\ara_language\src\cssPlugin;
/**
 * Class Bootstrap
 * @package Plugin\jtl_test
 */
class Bootstrap extends Bootstrapper
{
    /**
     * @var TestHelper
     */
    private $cssPlugin;


    /**
     * @inheritdoc
     */
    public function boot(Dispatcher $dispatcher)
    {
        parent::boot($dispatcher);
            $plugin = $this->getPlugin();
        if (Shop::isFrontend() === true || (isset($_REQUEST['kPlugin']) &&  $plugin->getID() == (int) $_REQUEST['kPlugin'])) {
            $this->cssPlugin = src\cssPlugin\cssPlugin::getInstance(
                $plugin,
                $this->getDB(),
                $this->getCache()
            );
        }
        if (Shop::isFrontend() === true) {
            $cfg = $this->cssPlugin->getConfig();
            if($cfg->pluginActive=='N') return;
            $dispatcher->listen('shop.hook.' . \HOOK_SMARTY_OUTPUTFILTER, function () use ($plugin) {
                $this->cssPlugin->hookSmartyOutputfilter();
            });
        }  else {
#            require_once $plugin->getPaths()->getBasePath() . 'includes/defines_inc.php';
#            $this->admin = new Admin($this->getDB(), Shop::Container()->getBackendLogService());
        }

    }        

    /**
     * @inheritdoc
     */
    public function installed()
    {
        $plugin  = $this->getPlugin();
        $this->getCache()->flushTags('cache_'.$plugin->getPluginID());
        parent::installed();
    }

    /**
     * @inheritdoc
     */
    public function updated($oldVersion, $newVersion)
    {
        $plugin  = $this->getPlugin();
        $this->getCache()->flushTags('cache_'.$plugin->getPluginID());
        \error_log('updated from ' . $oldVersion . ' to ' . $newVersion);
    }

    /**
     * @inheritdoc
     */
    public function uninstalled(bool $deleteData = true)
    {
        $plugin  = $this->getPlugin();
        if($deleteData === true) {
        }
        $this->getCache()->flushTags('cache_'.$plugin->getPluginID());
        parent::uninstalled($deleteData);
    }

    /**
     * @inheritdoc
     */

    /**
     * @inheritdoc
     */
    public function renderAdminMenuTab(string $tabName, int $menuID, JTLSmarty $smarty): string
    {


        $alert   = Shop::Container()->getAlertService();
        $cache   = Shop::Container()->getCache();
        $error   = null;
        $success = null;
        $plugin  = $this->getPlugin();
        if (Request::postInt('clear-cache') === 1) {
            if (Form::validateToken()) {
                // we used the plugin's ID as an additional cache tag, so we can flush the whole group
                $result = $cache->flushTags($plugin->getCache()->getGroup());
                // flushGroup() returns the number of deleted entries or FALSE if an error occured
                if (\is_numeric($result)) {
                    $alert->addAlert(Alert::TYPE_SUCCESS, __('Cache successfully flushed.'), 'succCacheFlush');
                } else {
                    $alert->addAlert(Alert::TYPE_ERROR, __('Could not flush cache!'), 'failedCacheFlush');
                }
            } else {
                $alert->addAlert(Alert::TYPE_ERROR, __('CSRF error!'), 'failedCsrfCheck');
            }
        }
        return $smarty->assign(
            'adminURL',
            Shop::getURL() . '/' . \PFAD_ADMIN . 'plugin.php?kPlugin=' . $plugin->getID()
        )
            ->fetch($plugin->getPaths()->getAdminPath() . 'template/'.$tabName.".tpl");
    }
}
